@@ -21,6 +21,7 @@
 #include <winpr/input.h>
 #include <winpr/sysinfo.h>
 
+#include <freerdp/server/server-common.h>
 #include <freerdp/codec/color.h>
 #include <freerdp/codec/region.h>
 #include <freerdp/log.h>
@@ -29,11 +30,10 @@
 
 #define TAG SERVER_TAG("shadow.mac")
 
-
 static macShadowSubsystem* g_Subsystem = NULL;
 
 static BOOL mac_shadow_input_synchronize_event(rdpShadowSubsystem* subsystem,
-        rdpShadowClient* client, UINT32 flags)
+                                               rdpShadowClient* client, UINT32 flags)
 {
 	if (!subsystem || !client)
 		return FALSE;
@@ -41,8 +41,8 @@ static BOOL mac_shadow_input_synchronize_event(rdpShadowSubsystem* subsystem,
 	return TRUE;
 }
 
-static BOOL mac_shadow_input_keyboard_event(rdpShadowSubsystem* subsystem,
-        rdpShadowClient* client, UINT16 flags, UINT16 code)
+static BOOL mac_shadow_input_keyboard_event(rdpShadowSubsystem* subsystem, rdpShadowClient* client,
+                                            UINT16 flags, UINT8 code)
 {
 	DWORD vkcode;
 	DWORD keycode;
@@ -62,23 +62,19 @@ static BOOL mac_shadow_input_keyboard_event(rdpShadowSubsystem* subsystem,
 	if (extended)
 		vkcode |= KBDEXT;
 
-	keycode = GetKeycodeFromVirtualKeyCode(vkcode, KEYCODE_TYPE_APPLE);
+	keycode = GetKeycodeFromVirtualKeyCode(vkcode, WINPR_KEYCODE_TYPE_APPLE);
 
-	if (keycode < 8)
-		return TRUE;
-
-	keycode -= 8;
 	source = CGEventSourceCreate(kCGEventSourceStateHIDSystemState);
 
 	if (flags & KBD_FLAGS_DOWN)
 	{
-		kbdEvent = CGEventCreateKeyboardEvent(source, (CGKeyCode) keycode, TRUE);
+		kbdEvent = CGEventCreateKeyboardEvent(source, (CGKeyCode)keycode, TRUE);
 		CGEventPost(kCGHIDEventTap, kbdEvent);
 		CFRelease(kbdEvent);
 	}
 	else if (flags & KBD_FLAGS_RELEASE)
 	{
-		kbdEvent = CGEventCreateKeyboardEvent(source, (CGKeyCode) keycode, FALSE);
+		kbdEvent = CGEventCreateKeyboardEvent(source, (CGKeyCode)keycode, FALSE);
 		CGEventPost(kCGHIDEventTap, kbdEvent);
 		CFRelease(kbdEvent);
 	}
@@ -87,8 +83,9 @@ static BOOL mac_shadow_input_keyboard_event(rdpShadowSubsystem* subsystem,
 	return TRUE;
 }
 
-static BOOL mac_shadow_input_unicode_keyboard_event(rdpShadowSubsystem*
-        subsystem, rdpShadowClient* client, UINT16 flags, UINT16 code)
+static BOOL mac_shadow_input_unicode_keyboard_event(rdpShadowSubsystem* subsystem,
+                                                    rdpShadowClient* client, UINT16 flags,
+                                                    UINT16 code)
 {
 	if (!subsystem || !client)
 		return FALSE;
@@ -96,8 +93,8 @@ static BOOL mac_shadow_input_unicode_keyboard_event(rdpShadowSubsystem*
 	return TRUE;
 }
 
-static BOOL mac_shadow_input_mouse_event(rdpShadowSubsystem* subsystem,
-        rdpShadowClient* client, UINT16 flags, UINT16 x, UINT16 y)
+static BOOL mac_shadow_input_mouse_event(rdpShadowSubsystem* subsystem, rdpShadowClient* client,
+                                         UINT16 flags, UINT16 x, UINT16 y)
 {
 	macShadowSubsystem* mac = (macShadowSubsystem*)subsystem;
 	UINT32 scrollX = 0;
@@ -120,19 +117,16 @@ static BOOL mac_shadow_input_mouse_event(rdpShadowSubsystem* subsystem,
 			scrollY = (flags & WheelRotationMask) / 120;
 		}
 
-		CGEventSourceRef source = CGEventSourceCreate(
-		                              kCGEventSourceStateHIDSystemState);
-		CGEventRef scroll = CGEventCreateScrollWheelEvent(source,
-		                    kCGScrollEventUnitLine,
-		                    wheelCount, scrollY, scrollX);
+		CGEventSourceRef source = CGEventSourceCreate(kCGEventSourceStateHIDSystemState);
+		CGEventRef scroll = CGEventCreateScrollWheelEvent(source, kCGScrollEventUnitLine,
+		                                                  wheelCount, scrollY, scrollX);
 		CGEventPost(kCGHIDEventTap, scroll);
 		CFRelease(scroll);
 		CFRelease(source);
 	}
 	else
 	{
-		CGEventSourceRef source = CGEventSourceCreate(
-		                              kCGEventSourceStateHIDSystemState);
+		CGEventSourceRef source = CGEventSourceCreate(kCGEventSourceStateHIDSystemState);
 		CGEventType mouseType = kCGEventNull;
 		CGMouseButton mouseButton = kCGMouseButtonLeft;
 
@@ -147,8 +141,8 @@ static BOOL mac_shadow_input_mouse_event(rdpShadowSubsystem* subsystem,
 			else
 				mouseType = kCGEventMouseMoved;
 
-			CGEventRef move = CGEventCreateMouseEvent(source, mouseType, CGPointMake(x, y),
-			                  mouseButton);
+			CGEventRef move =
+			    CGEventCreateMouseEvent(source, mouseType, CGPointMake(x, y), mouseButton);
 			CGEventPost(kCGHIDEventTap, move);
 			CFRelease(move);
 		}
@@ -199,8 +193,8 @@ static BOOL mac_shadow_input_mouse_event(rdpShadowSubsystem* subsystem,
 			}
 		}
 
-		CGEventRef mouseEvent = CGEventCreateMouseEvent(source, mouseType,
-		                        CGPointMake(x, y), mouseButton);
+		CGEventRef mouseEvent =
+		    CGEventCreateMouseEvent(source, mouseType, CGPointMake(x, y), mouseButton);
 		CGEventPost(kCGHIDEventTap, mouseEvent);
 		CFRelease(mouseEvent);
 		CFRelease(source);
@@ -210,7 +204,8 @@ static BOOL mac_shadow_input_mouse_event(rdpShadowSubsystem* subsystem,
 }
 
 static BOOL mac_shadow_input_extended_mouse_event(rdpShadowSubsystem* subsystem,
-        rdpShadowClient* client, UINT16 flags, UINT16 x, UINT16 y)
+                                                  rdpShadowClient* client, UINT16 flags, UINT16 x,
+                                                  UINT16 y)
 {
 	if (!subsystem || !client)
 		return FALSE;
@@ -277,23 +272,22 @@ static int mac_shadow_capture_stop(macShadowSubsystem* subsystem)
 
 static int mac_shadow_capture_get_dirty_region(macShadowSubsystem* subsystem)
 {
-	size_t index;
 	size_t numRects;
 	const CGRect* rects;
 	RECTANGLE_16 invalidRect;
 	rdpShadowSurface* surface = subsystem->common.server->surface;
-	rects = CGDisplayStreamUpdateGetRects(subsystem->lastUpdate,
-	                                      kCGDisplayStreamUpdateDirtyRects, &numRects);
+	rects = CGDisplayStreamUpdateGetRects(subsystem->lastUpdate, kCGDisplayStreamUpdateDirtyRects,
+	                                      &numRects);
 
 	if (!numRects)
 		return -1;
 
-	for (index = 0; index < numRects; index++)
+	for (size_t index = 0; index < numRects; index++)
 	{
-		invalidRect.left = (UINT16) rects[index].origin.x;
-		invalidRect.top = (UINT16) rects[index].origin.y;
-		invalidRect.right = invalidRect.left + (UINT16) rects[index].size.width;
-		invalidRect.bottom = invalidRect.top + (UINT16) rects[index].size.height;
+		invalidRect.left = (UINT16)rects[index].origin.x;
+		invalidRect.top = (UINT16)rects[index].origin.y;
+		invalidRect.right = invalidRect.left + (UINT16)rects[index].size.width;
+		invalidRect.bottom = invalidRect.top + (UINT16)rects[index].size.height;
 
 		if (subsystem->retina)
 		{
@@ -304,20 +298,18 @@ static int mac_shadow_capture_get_dirty_region(macShadowSubsystem* subsystem)
 			invalidRect.bottom /= 2;
 		}
 
-		region16_union_rect(&(surface->invalidRegion), &(surface->invalidRegion),
-		                    &invalidRect);
+		region16_union_rect(&(surface->invalidRegion), &(surface->invalidRegion), &invalidRect);
 	}
 
 	return 0;
 }
 
-static int freerdp_image_copy_from_retina(BYTE* pDstData, DWORD DstFormat,
-        int nDstStep, int nXDst, int nYDst,
-        int nWidth, int nHeight, BYTE* pSrcData, int nSrcStep, int nXSrc, int nYSrc)
+static int freerdp_image_copy_from_retina(BYTE* pDstData, DWORD DstFormat, int nDstStep, int nXDst,
+                                          int nYDst, int nWidth, int nHeight, BYTE* pSrcData,
+                                          int nSrcStep, int nXSrc, int nYSrc)
 {
 	BYTE* pSrcPixel;
 	BYTE* pDstPixel;
-	int x, y;
 	int nSrcPad;
 	int nDstPad;
 	int srcBitsPerPixel;
@@ -330,8 +322,8 @@ static int freerdp_image_copy_from_retina(BYTE* pDstData, DWORD DstFormat,
 	if (nSrcStep < 0)
 		nSrcStep = srcBytesPerPixel * nWidth;
 
-	dstBitsPerPixel = GetBitsPerPixel(DstFormat);
-	dstBytesPerPixel = GetBytesPerPixel(DstFormat);
+	dstBitsPerPixel = FreeRDPGetBitsPerPixel(DstFormat);
+	dstBytesPerPixel = FreeRDPGetBytesPerPixel(DstFormat);
 
 	if (nDstStep < 0)
 		nDstStep = dstBytesPerPixel * nWidth;
@@ -341,22 +333,19 @@ static int freerdp_image_copy_from_retina(BYTE* pDstData, DWORD DstFormat,
 	pSrcPixel = &pSrcData[(nYSrc * nSrcStep) + (nXSrc * 4)];
 	pDstPixel = &pDstData[(nYDst * nDstStep) + (nXDst * 4)];
 
-	for (y = 0; y < nHeight; y++)
+	for (int y = 0; y < nHeight; y++)
 	{
-		for (x = 0; x < nWidth; x++)
+		for (int x = 0; x < nWidth; x++)
 		{
 			UINT32 R, G, B;
 			UINT32 color;
 			/* simple box filter scaling, could be improved with better algorithm */
-			B = pSrcPixel[0] + pSrcPixel[4] + pSrcPixel[nSrcStep + 0] + pSrcPixel[nSrcStep +
-			        4];
-			G = pSrcPixel[1] + pSrcPixel[5] + pSrcPixel[nSrcStep + 1] + pSrcPixel[nSrcStep +
-			        5];
-			R = pSrcPixel[2] + pSrcPixel[6] + pSrcPixel[nSrcStep + 2] + pSrcPixel[nSrcStep +
-			        6];
+			B = pSrcPixel[0] + pSrcPixel[4] + pSrcPixel[nSrcStep + 0] + pSrcPixel[nSrcStep + 4];
+			G = pSrcPixel[1] + pSrcPixel[5] + pSrcPixel[nSrcStep + 1] + pSrcPixel[nSrcStep + 5];
+			R = pSrcPixel[2] + pSrcPixel[6] + pSrcPixel[nSrcStep + 2] + pSrcPixel[nSrcStep + 6];
 			pSrcPixel += 8;
 			color = FreeRDPGetColor(DstFormat, R >> 2, G >> 2, B >> 2, 0xFF);
-			WriteColor(pDstPixel, DstFormat, color);
+			FreeRDPWriteColor(pDstPixel, DstFormat, color);
 			pDstPixel += dstBytesPerPixel;
 		}
 
@@ -367,109 +356,111 @@ static int freerdp_image_copy_from_retina(BYTE* pDstData, DWORD DstFormat,
 	return 1;
 }
 
-static void (^mac_capture_stream_handler)(CGDisplayStreamFrameStatus, uint64_t,
-        IOSurfaceRef, CGDisplayStreamUpdateRef) =
-            ^(CGDisplayStreamFrameStatus status, uint64_t displayTime,
-              IOSurfaceRef frameSurface, CGDisplayStreamUpdateRef updateRef)
-{
-	int x, y;
-	int count;
-	int width;
-	int height;
-	int nSrcStep;
-	BYTE* pSrcData;
-	RECTANGLE_16 surfaceRect;
-	const RECTANGLE_16* extents;
-	macShadowSubsystem* subsystem = g_Subsystem;
-	rdpShadowServer* server = subsystem->common.server;
-	rdpShadowSurface* surface = server->surface;
-	count = ArrayList_Count(server->clients);
+static void (^mac_capture_stream_handler)(
+    CGDisplayStreamFrameStatus, uint64_t, IOSurfaceRef,
+    CGDisplayStreamUpdateRef) = ^(CGDisplayStreamFrameStatus status, uint64_t displayTime,
+                                  IOSurfaceRef frameSurface, CGDisplayStreamUpdateRef updateRef) {
+  int x, y;
+  int count;
+  int width;
+  int height;
+  int nSrcStep;
+  BOOL empty;
+  BYTE* pSrcData;
+  RECTANGLE_16 surfaceRect;
+  const RECTANGLE_16* extents;
+  macShadowSubsystem* subsystem = g_Subsystem;
+  rdpShadowServer* server = subsystem->common.server;
+  rdpShadowSurface* surface = server->surface;
+  count = ArrayList_Count(server->clients);
 
-	if (count < 1)
-		return;
+  if (count < 1)
+	  return;
 
-	mac_shadow_capture_get_dirty_region(subsystem);
-	surfaceRect.left = 0;
-	surfaceRect.top = 0;
-	surfaceRect.right = surface->width;
-	surfaceRect.bottom = surface->height;
-	region16_intersect_rect(&(surface->invalidRegion), &(surface->invalidRegion),
-	                        &surfaceRect);
+  EnterCriticalSection(&(surface->lock));
+  mac_shadow_capture_get_dirty_region(subsystem);
+  surfaceRect.left = 0;
+  surfaceRect.top = 0;
+  surfaceRect.right = surface->width;
+  surfaceRect.bottom = surface->height;
+  region16_intersect_rect(&(surface->invalidRegion), &(surface->invalidRegion), &surfaceRect);
+  empty = region16_is_empty(&(surface->invalidRegion));
+  LeaveCriticalSection(&(surface->lock));
 
-	if (!region16_is_empty(&(surface->invalidRegion)))
-	{
-		extents = region16_extents(&(surface->invalidRegion));
-		x = extents->left;
-		y = extents->top;
-		width = extents->right - extents->left;
-		height = extents->bottom - extents->top;
-		IOSurfaceLock(frameSurface, kIOSurfaceLockReadOnly, NULL);
-		pSrcData = (BYTE*) IOSurfaceGetBaseAddress(frameSurface);
-		nSrcStep = (int) IOSurfaceGetBytesPerRow(frameSurface);
+  if (!empty)
+  {
+	  extents = region16_extents(&(surface->invalidRegion));
+	  x = extents->left;
+	  y = extents->top;
+	  width = extents->right - extents->left;
+	  height = extents->bottom - extents->top;
+	  IOSurfaceLock(frameSurface, kIOSurfaceLockReadOnly, NULL);
+	  pSrcData = (BYTE*)IOSurfaceGetBaseAddress(frameSurface);
+	  nSrcStep = (int)IOSurfaceGetBytesPerRow(frameSurface);
 
-		if (subsystem->retina)
-		{
-			freerdp_image_copy_from_retina(surface->data, surface->format,
-			                               surface->scanline,
-			                               x, y, width, height, pSrcData, nSrcStep, x, y);
-		}
-		else
-		{
-			freerdp_image_copy(surface->data, surface->format, surface->scanline,
-			                   x, y, width, height, pSrcData, PIXEL_FORMAT_BGRX32, nSrcStep, x, y, NULL, FREERDP_FLIP_NONE);
-		}
+	  if (subsystem->retina)
+	  {
+		  freerdp_image_copy_from_retina(surface->data, surface->format, surface->scanline, x, y,
+			                             width, height, pSrcData, nSrcStep, x, y);
+	  }
+	  else
+	  {
+		  freerdp_image_copy_no_overlap(surface->data, surface->format, surface->scanline, x, y,
+			                            width, height, pSrcData, PIXEL_FORMAT_BGRX32, nSrcStep, x,
+			                            y, NULL, FREERDP_FLIP_NONE);
+	  }
+	  LeaveCriticalSection(&(surface->lock));
 
-		IOSurfaceUnlock(frameSurface, kIOSurfaceLockReadOnly, NULL);
-		ArrayList_Lock(server->clients);
-		count = ArrayList_Count(server->clients);
-		EnterCriticalSection(&(surface->lock));
-		shadow_subsystem_frame_update(&subsystem->common);
-		LeaveCriticalSection(&(surface->lock));
+	  IOSurfaceUnlock(frameSurface, kIOSurfaceLockReadOnly, NULL);
+	  ArrayList_Lock(server->clients);
+	  count = ArrayList_Count(server->clients);
+	  shadow_subsystem_frame_update(&subsystem->common);
 
-		if (count == 1)
-		{
-			rdpShadowClient* client;
-			client = (rdpShadowClient*) ArrayList_GetItem(server->clients, 0);
+	  if (count == 1)
+	  {
+		  rdpShadowClient* client;
+		  client = (rdpShadowClient*)ArrayList_GetItem(server->clients, 0);
 
-			if (client)
-			{
-				subsystem->common.captureFrameRate = shadow_encoder_preferred_fps(client->encoder);
-			}
-		}
+		  if (client)
+		  {
+			  subsystem->common.captureFrameRate = shadow_encoder_preferred_fps(client->encoder);
+		  }
+	  }
 
-		ArrayList_Unlock(server->clients);
-		region16_clear(&(surface->invalidRegion));
-	}
+	  ArrayList_Unlock(server->clients);
+	  EnterCriticalSection(&(surface->lock));
+	  region16_clear(&(surface->invalidRegion));
+	  LeaveCriticalSection(&(surface->lock));
+  }
 
-	if (status != kCGDisplayStreamFrameStatusFrameComplete)
-	{
-		switch (status)
-		{
-			case kCGDisplayStreamFrameStatusFrameIdle:
-				break;
+  if (status != kCGDisplayStreamFrameStatusFrameComplete)
+  {
+	  switch (status)
+	  {
+		  case kCGDisplayStreamFrameStatusFrameIdle:
+			  break;
 
-			case kCGDisplayStreamFrameStatusStopped:
-				break;
+		  case kCGDisplayStreamFrameStatusStopped:
+			  break;
 
-			case kCGDisplayStreamFrameStatusFrameBlank:
-				break;
+		  case kCGDisplayStreamFrameStatusFrameBlank:
+			  break;
 
-			default:
-				break;
-		}
-	}
-	else if (!subsystem->lastUpdate)
-	{
-		CFRetain(updateRef);
-		subsystem->lastUpdate = updateRef;
-	}
-	else
-	{
-		CGDisplayStreamUpdateRef tmpRef = subsystem->lastUpdate;
-		subsystem->lastUpdate = CGDisplayStreamUpdateCreateMergedUpdate(tmpRef,
-		                        updateRef);
-		CFRelease(tmpRef);
-	}
+		  default:
+			  break;
+	  }
+  }
+  else if (!subsystem->lastUpdate)
+  {
+	  CFRetain(updateRef);
+	  subsystem->lastUpdate = updateRef;
+  }
+  else
+  {
+	  CGDisplayStreamUpdateRef tmpRef = subsystem->lastUpdate;
+	  subsystem->lastUpdate = CGDisplayStreamUpdateCreateMergedUpdate(tmpRef, updateRef);
+	  CFRelease(tmpRef);
+  }
 };
 
 static int mac_shadow_capture_init(macShadowSubsystem* subsystem)
@@ -480,13 +471,13 @@ static int mac_shadow_capture_init(macShadowSubsystem* subsystem)
 	CGDirectDisplayID displayId;
 	displayId = CGMainDisplayID();
 	subsystem->captureQueue = dispatch_queue_create("mac.shadow.capture", NULL);
-	keys[0] = (void*) kCGDisplayStreamShowCursor;
-	values[0] = (void*) kCFBooleanFalse;
-	opts = CFDictionaryCreate(kCFAllocatorDefault, (const void**) keys,
-	                          (const void**) values, 1, NULL, NULL);
-	subsystem->stream = CGDisplayStreamCreateWithDispatchQueue(displayId,
-	                    subsystem->pixelWidth, subsystem->pixelHeight,
-	                    'BGRA', opts, subsystem->captureQueue, mac_capture_stream_handler);
+	keys[0] = (void*)kCGDisplayStreamShowCursor;
+	values[0] = (void*)kCFBooleanFalse;
+	opts = CFDictionaryCreate(kCFAllocatorDefault, (const void**)keys, (const void**)values, 1,
+	                          NULL, NULL);
+	subsystem->stream = CGDisplayStreamCreateWithDispatchQueue(
+	    displayId, subsystem->pixelWidth, subsystem->pixelHeight, 'BGRA', opts,
+	    subsystem->captureQueue, mac_capture_stream_handler);
 	CFRelease(opts);
 	return 1;
 }
@@ -496,8 +487,7 @@ static int mac_shadow_screen_grab(macShadowSubsystem* subsystem)
 	return 1;
 }
 
-static int mac_shadow_subsystem_process_message(macShadowSubsystem* subsystem,
-        wMessage* message)
+static int mac_shadow_subsystem_process_message(macShadowSubsystem* subsystem, wMessage* message)
 {
 	rdpShadowServer* server = subsystem->common.server;
 	rdpShadowSurface* surface = server->surface;
@@ -511,7 +501,7 @@ static int mac_shadow_subsystem_process_message(macShadowSubsystem* subsystem,
 			break;
 
 		default:
-			WLog_ERR(TAG, "Unknown message id: %"PRIu32"", message->id);
+			WLog_ERR(TAG, "Unknown message id: %" PRIu32 "", message->id);
 			break;
 	}
 
@@ -569,11 +559,11 @@ static DWORD WINAPI mac_shadow_subsystem_thread(LPVOID arg)
 	return 0;
 }
 
-static int mac_shadow_enum_monitors(MONITOR_DEF* monitors, int maxMonitors)
+static UINT32 mac_shadow_enum_monitors(MONITOR_DEF* monitors, UINT32 maxMonitors)
 {
 	int index;
 	size_t wide, high;
-	int numMonitors = 0;
+	UINT32 numMonitors = 0;
 	MONITOR_DEF* monitor;
 	CGDirectDisplayID displayId;
 	displayId = CGMainDisplayID();
@@ -586,22 +576,25 @@ static int mac_shadow_enum_monitors(MONITOR_DEF* monitors, int maxMonitors)
 	monitor = &monitors[index];
 	monitor->left = 0;
 	monitor->top = 0;
-	monitor->right = (int) wide;
-	monitor->bottom = (int) high;
+	monitor->right = (int)wide;
+	monitor->bottom = (int)high;
 	monitor->flags = 1;
 	return numMonitors;
 }
 
-static int mac_shadow_subsystem_init(macShadowSubsystem* subsystem)
+static int mac_shadow_subsystem_init(rdpShadowSubsystem* rdpsubsystem)
 {
+	macShadowSubsystem* subsystem = (macShadowSubsystem*)rdpsubsystem;
 	g_Subsystem = subsystem;
+
 	mac_shadow_detect_monitors(subsystem);
 	mac_shadow_capture_init(subsystem);
 	return 1;
 }
 
-static int mac_shadow_subsystem_uninit(macShadowSubsystem* subsystem)
+static int mac_shadow_subsystem_uninit(rdpShadowSubsystem* rdpsubsystem)
 {
+	macShadowSubsystem* subsystem = (macShadowSubsystem*)rdpsubsystem;
 	if (!subsystem)
 		return -1;
 
@@ -614,8 +607,9 @@ static int mac_shadow_subsystem_uninit(macShadowSubsystem* subsystem)
 	return 1;
 }
 
-static int mac_shadow_subsystem_start(macShadowSubsystem* subsystem)
+static int mac_shadow_subsystem_start(rdpShadowSubsystem* rdpsubsystem)
 {
+	macShadowSubsystem* subsystem = (macShadowSubsystem*)rdpsubsystem;
 	HANDLE thread;
 
 	if (!subsystem)
@@ -623,8 +617,7 @@ static int mac_shadow_subsystem_start(macShadowSubsystem* subsystem)
 
 	mac_shadow_capture_start(subsystem);
 
-	if (!(thread = CreateThread(NULL, 0, mac_shadow_subsystem_thread,
-	                            (void*) subsystem, 0, NULL)))
+	if (!(thread = CreateThread(NULL, 0, mac_shadow_subsystem_thread, (void*)subsystem, 0, NULL)))
 	{
 		WLog_ERR(TAG, "Failed to create thread");
 		return -1;
@@ -633,7 +626,7 @@ static int mac_shadow_subsystem_start(macShadowSubsystem* subsystem)
 	return 1;
 }
 
-static int mac_shadow_subsystem_stop(macShadowSubsystem* subsystem)
+static int mac_shadow_subsystem_stop(rdpShadowSubsystem* subsystem)
 {
 	if (!subsystem)
 		return -1;
@@ -641,7 +634,7 @@ static int mac_shadow_subsystem_stop(macShadowSubsystem* subsystem)
 	return 1;
 }
 
-static void mac_shadow_subsystem_free(macShadowSubsystem* subsystem)
+static void mac_shadow_subsystem_free(rdpShadowSubsystem* subsystem)
 {
 	if (!subsystem)
 		return;
@@ -650,10 +643,9 @@ static void mac_shadow_subsystem_free(macShadowSubsystem* subsystem)
 	free(subsystem);
 }
 
-static macShadowSubsystem* mac_shadow_subsystem_new(void)
+static rdpShadowSubsystem* mac_shadow_subsystem_new(void)
 {
-	macShadowSubsystem* subsystem;
-	subsystem = (macShadowSubsystem*) calloc(1, sizeof(macShadowSubsystem));
+	macShadowSubsystem* subsystem = calloc(1, sizeof(macShadowSubsystem));
 
 	if (!subsystem)
 		return NULL;
@@ -663,17 +655,26 @@ static macShadowSubsystem* mac_shadow_subsystem_new(void)
 	subsystem->common.UnicodeKeyboardEvent = mac_shadow_input_unicode_keyboard_event;
 	subsystem->common.MouseEvent = mac_shadow_input_mouse_event;
 	subsystem->common.ExtendedMouseEvent = mac_shadow_input_extended_mouse_event;
-	return subsystem;
+	return &subsystem->common;
 }
 
-FREERDP_API int Mac_ShadowSubsystemEntry(RDP_SHADOW_ENTRY_POINTS* pEntryPoints)
+FREERDP_API const char* ShadowSubsystemName(void)
 {
-	pEntryPoints->New = (pfnShadowSubsystemNew) mac_shadow_subsystem_new;
-	pEntryPoints->Free = (pfnShadowSubsystemFree) mac_shadow_subsystem_free;
-	pEntryPoints->Init = (pfnShadowSubsystemInit) mac_shadow_subsystem_init;
-	pEntryPoints->Uninit = (pfnShadowSubsystemInit) mac_shadow_subsystem_uninit;
-	pEntryPoints->Start = (pfnShadowSubsystemStart) mac_shadow_subsystem_start;
-	pEntryPoints->Stop = (pfnShadowSubsystemStop) mac_shadow_subsystem_stop;
-	pEntryPoints->EnumMonitors = (pfnShadowEnumMonitors) mac_shadow_enum_monitors;
+	return "Mac";
+}
+
+FREERDP_API int ShadowSubsystemEntry(RDP_SHADOW_ENTRY_POINTS* pEntryPoints)
+{
+	char name[] = "mac shadow subsystem";
+	char* arg[] = { name };
+
+	freerdp_server_warn_unmaintained(ARRAYSIZE(arg), arg);
+	pEntryPoints->New = mac_shadow_subsystem_new;
+	pEntryPoints->Free = mac_shadow_subsystem_free;
+	pEntryPoints->Init = mac_shadow_subsystem_init;
+	pEntryPoints->Uninit = mac_shadow_subsystem_uninit;
+	pEntryPoints->Start = mac_shadow_subsystem_start;
+	pEntryPoints->Stop = mac_shadow_subsystem_stop;
+	pEntryPoints->EnumMonitors = mac_shadow_enum_monitors;
 	return 1;
 }
